@@ -4,17 +4,22 @@
 # Copyright (c) Stuart Quin.
 # Distributed under the terms of the Modified BSD License.
 
-"""
-TODO: Add module docstring
-"""
-
 from ipywidgets import DOMWidget, ValueWidget
 from traitlets import Unicode, List
 from ._frontend import module_name, module_version
 
 
 class AnnotateWidget(DOMWidget, ValueWidget):
-    """TODO: Add docstring here"""
+    """Interactive text annotation widget for Jupyter
+
+    Keyword arguments:
+    docs -- List of string documents (required)
+    labels -- List of labels (default [])
+    spans -- List of Lists containing span dicts, (default [])
+
+    span dict format:
+    {'start': 2, 'end': 7, 'text': 'Hello', 'label': 'Test'},
+    """
 
     _model_name = Unicode("AnnotateModel").tag(sync=True)
     _model_module = Unicode(module_name).tag(sync=True)
@@ -25,4 +30,4 @@ class AnnotateWidget(DOMWidget, ValueWidget):
 
     docs = List(trait=Unicode()).tag(sync=True)
     spans = List([]).tag(sync=True)
-    labels = List().tag(sync=True)
+    labels = List([]).tag(sync=True)
