@@ -10,7 +10,7 @@
 // dynamically.
 // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
 (window as any).__webpack_public_path__ =
-  document.querySelector('body')!.getAttribute('data-base-url') +
-  'nbextensions/jupyterannotate';
+  document.querySelector("body")!.getAttribute("data-base-url") +
+  "nbextensions/jupyterannotate";
 
-export * from './index';
+export * from "./index";
