@@ -1,5 +1,5 @@
 // Copyright (c) Stuart Quin
 // Distributed under the terms of the Modified BSD License.
 
-export * from './version';
-export * from './widget';
+export * from "./version";
+export * from "./widget";
