@@ -4,7 +4,7 @@
 // eslint-disable-next-line @typescript-eslint/ban-ts-comment
 // @ts-ignore
 // eslint-disable-next-line @typescript-eslint/no-var-requires
-const data = require('../package.json');
+const data = require("../package.json");
 
 /**
  * The _model_module_version/_view_module_version this package implements.
